magneticalc.Constraint.Constraint

# ``magneticalc`.`Constraint`.`Constraint``

class documentation

`class Constraint:`

Constructor: `Constraint(norm_type, comparison_type, _min, _max, permeability)`

View In Hierarchy

Constraint class.

Method | `__init__` | Initializes the constraint.
Method | `evaluate` | Evaluate this constraint at some point.
Class Variable | `Comparison_Types_Supported` | Undocumented
Class Variable | `Norm_Types_Supported` | Supported norm types using minimum and maximum angles in degrees.
Class Variable | `Norm_Types_Supported_Degrees` | Supported comparison types.
Instance Variable | `permeability` | Undocumented
Instance Variable | `_comparison_type` | Undocumented
Instance Variable | `_max` | Undocumented
Instance Variable | `_min` | Undocumented
Instance Variable | `_norm_type` | Undocumented

def __init__(self, norm_type: `int`, comparison_type: `int`, _min: `float`, _max: `float`, permeability: `float`):

Initializes the constraint.

Parameters
norm_type: `int` | Norm type
comparison_type: `int` | Comparison type
_min: `float` | Minimum value
_max: `float` | Maximum value
permeability: `float` | Relative permeability µ_r

def evaluate(self, point: `np.ndarray | list[float]`) -> `bool`:

Evaluate this constraint at some point.

Parameters
point: `np.ndarray | list[float]` | Point (3D vector)

Returns
`bool` | Undocumented

Comparison_Types_Supported =

Undocumented

Norm_Types_Supported =

Supported norm types using minimum and maximum angles in degrees.

Norm_Types_Supported_Degrees =

Supported comparison types.

permeability =

Undocumented

_comparison_type =

Undocumented

_max =

Undocumented

_min =

Undocumented

_norm_type =

Undocumented